# -*- coding: utf-8 -*-
from unittest import TestCase
import heimdall
import pytest  # just for skipping


class HeraJSONTest(TestCase):

    def setUp(self):
        args = {
            'format': 'json:hera',
            'url': './tests/resources/hera.json',
            }
        self.config = heimdall.Config(**args)

    def tearDown(self):
        self.config = None

    @pytest.mark.skip(reason="Avoid local test files")
    def test_get_database(self):
        tree = heimdall.getDatabase(self.config)
        from lxml import etree
        #content = etree.tostring(tree, pretty_print=True, encoding=str)
        #from .logger import getLogger
        #getLogger(__name__).info(content)
        root = tree.getroot()
        self.assertEqual(root.tag, 'hera')
        self.assertEqual(len(root.xpath('//items')), 1)
        self.assertEqual(len(root.xpath('//entities')), 1)
        self.assertEqual(len(root.xpath('//properties')), 1)

        properties = root.xpath('//properties/property')
        self.assertEqual(len(properties), 3)
        for p in properties:
            self.assertEqual(p.tag, 'property')
            pid = p.get('id')
            # assert this pid (ie. propertyId) is unique across all properties
            self.assertEqual(len(root.xpath(f"//property[@id='{pid}']")), 1)
            # get child nodes of this property
            children = root.xpath(f"//property[@id='{pid}']/child::*")
            self.assertEqual(len(children), 3)
            self.assertEqual(children[0].tag, 'type')
            expected = ['name', 'description']
            for c in children[1:]:
                self.assertTrue(c.tag in expected)

        entities = root.xpath('//entities/entity')
        self.assertEqual(len(entities), 0)

        items = root.xpath('//items/item')
        self.assertEqual(len(items), 220)
        for item in items:
            self.assertEqual(item.tag, 'item')
            self.assertIsNone(item.get('id'))
            self.assertIsNotNone(item.get('eid'))
            for metadata in item:
                self.assertEqual(metadata.tag, 'metadata')
                self.assertIsNotNone(metadata.get('pid'))
                self.assertIsNotNone(metadata.text)
